---
description: Continuously accept log events through another upstream Vector instance
---

<!---
!!!WARNING!!!!

This file is autogenerated! Please do not manually edit this file.
Instead, please modify the contents of `scripts/metadata.toml`.
-->


# vector source

![](../../../assets/vector-source.svg)

{% hint style="warning" %}
The `vector` source is in beta. Please see the current [enhancements](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Source%3A+vector%22+label%3A%22Type%3A+Enhancement%22) and [bugs](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Source%3A+vector%22+label%3A%22Type%3A+Bug%22) for known issues. We kindly ask that you [add any missing issues](https://github.com/timberio/vector/issues/new?labels=Source%3A+vector) as it will help shape the roadmap of this component.
{% endhint %}
The `vector` source continuously ingests [`log`][docs.log_event] events through another upstream Vector instance.

## Config File

{% code-tabs %}
{% code-tabs-item title="vector.toml (example)" %}
```coffeescript
[sources.my_vector_source]
  # REQUIRED - General
  type = "vector" # must be: vector

  # OPTIONAL - General
  address = "0.0.0.0:9000" # no default
  shutdown_timeout_secs = 30 # default, seconds
```
{% endcode-tabs-item %}
{% code-tabs-item title="vector.toml (schema)" %}
```coffeescript
[sources.<source-id>]
  # REQUIRED - General
  type = {"vector"}

  # OPTIONAL - General
  address = "<string>"
  shutdown_timeout_secs = <int>
```
{% endcode-tabs-item %}
{% code-tabs-item title="vector.toml (specification)" %}
```coffeescript
[sources.vector]
  # REQUIRED - General

  # The component type
  #
  # * must be: vector
  type = "vector"

  # OPTIONAL - General

  # The TCP address to bind to.
  #
  # * no default
  address = "0.0.0.0:9000"

  # The timeout before a connection is forcefully closed during shutdown.
  #
  # * default: 30
  # * seconds
  shutdown_timeout_secs = 30
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## Options

| Key  | Type  | Description |
| :--- | :---: | :---------- |
| **REQUIRED** | | |
| `type` | `string` | The component type<br />`required` `enum: "vector"` |
| **OPTIONAL** | | |
| `address` | `string` | The TCP address to bind to.<br />`no default` `example: "0.0.0.0:9000"` |
| `shutdown_timeout_secs` | `int` | The timeout before a connection is forcefully closed during shutdown.<br />`default: 30` `unit: seconds` |





## How It Works

### Delivery Guarantee

Due to the nature of this component, it offers a **best effort**
delivery guarantee.

### Encoding

Data is encoded via Vector's [event protobuf][url.event_proto] before it is sent over the wire.

### Message Acking

Currently, Vector does not perform any application level message acknowledgement. While rare, this means the individual message could be lost. See [Issue #492][url.issue_492] for more info.

### TCP Protocol

Upstream Vector instances forward data to downstream Vector instances via the TCP protocol.

## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring_logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open source issues](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Source%3A+vector%22).
2. [Search the forum][url.search_forum] for any similar issues.
2. Reach out to the [community][url.community] for help.

## Resources

* [**Issues**](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Source%3A+vector%22) - [enhancements](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Source%3A+vector%22+label%3A%22Type%3A+Enhancement%22) - [bugs](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Source%3A+vector%22+label%3A%22Type%3A+Bug%22)
* [**Source code**](https://github.com/timberio/vector/tree/master/src/source/vector.rs)


[docs.log_event]: ../../../about/data-model.md#log
[docs.monitoring_logs]: ../../../usage/administration/monitoring.md#logs
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[url.community]: https://vector.dev/community
[url.event_proto]: https://github.com/timberio/vector/blob/master/proto/event.proto
[url.issue_492]: https://github.com/timberio/vector/issues/492
[url.search_forum]: https://forum.vector.dev/search?expanded=true
