---
description: add one or more fields
---

<!---
!!!WARNING!!!!

This file is autogenerated! Please do not manually edit this file.
Instead, please modify the contents of `scripts/metadata.toml`.
-->


# add_fields transform

![](../../../assets/add_fields-transform.svg)


The `add_fields` transforms accepts [`log`][docs.log_event] events and allows you to add one or more fields.

## Config File

{% code-tabs %}
{% code-tabs-item title="example" %}
```coffeescript
[transforms.my_add_fields_transform]
  # REQUIRED - General
  type = "add_fields" # must be: add_fields
  inputs = ["my-source-id"]

  # REQUIRED - Fields
  [transforms.my_add_fields_transform.fields]
    new_string_field = "string value"
    new_int_field = 1
    new_float_field = 1.2
    new_bool_field = true
```
{% endcode-tabs-item %}
{% code-tabs-item title="schema" %}
```coffeescript
[transforms.<transform-id>]
  # REQUIRED - General
  type = {"add_fields"}
  inputs = "<string>"

  # REQUIRED - Fields
  [transforms.<transform-id>.fields]
    * = "<string>"
```
{% endcode-tabs-item %}
{% code-tabs-item title="specification" %}
```coffeescript
[transforms.add_fields]
  # REQUIRED - General

  # The component type
  #
  # * must be: add_fields
  type = "add_fields"

  # A list of upstream source for more info.
  inputs = ["my-source-id"]

  # REQUIRED - Fields
  [transforms.add_fields.fields]

    # A key/value pair representing the new field to be added. Accepts all
    # supported types. Use `.` for adding nested fields.
    #
    # * no default
    new_string_field = "string value"
    new_int_field = 1
    new_float_field = 1.2
    new_bool_field = true
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## Options

| Key  | Type  | Description |
| :--- | :---: | :---------- |
| **REQUIRED** - General | | |
| `type` | `string` | The component type<br />`required` `enum: "add_fields"` |
| `inputs` | `string` | A list of upstream [source][docs.sources] or [transform][docs.transforms] IDs. See [Config Composition][docs.config_composition] for more info.<br />`required` `example: ["my-source-id"]` |
| **REQUIRED** - Fields | | |
| `fields.*` | `string` | A key/value pair representing the new field to be added. Accepts all [supported types][docs.config_value_types]. Use `.` for adding nested fields.<br />`no default` `example: (see above)` |

## Examples



Given the following configuration:

{% code-tabs %}
{% code-tabs-item title="vector.toml" %}
```coffeescript
[transforms.my_transform]
  type = "add_fields"
  inputs = [...]

  [transforms.my_transform.fields]
    field1 = "string value"
    field2 = 1
    field3 = 2.0
    field4 = true
    field5 = 2019-05-27T07:32:00Z
    field6 = ["item 1", "item 2"]
    field7.nested = "nested value",
    field8 = "#{HOSTNAME}"
```
{% endcode-tabs-item %}
{% endcode-tabs %}

A [`log` event][docs.log_event] will be emitted with the following structure:

{% code-tabs %}
{% code-tabs-item title="log" %}
```javascript
{
  // ... existing fields
  "field1": "string value",
  "field2": 1,
  "field3": 2.0,
  "field4": true,
  "field5": <timestamp:2019-05-27T07:32:00Z>,
  "field6": ["item1", "item2"],
  "field7.nested": "nested value",
  "field8": "my.hostname.com"
}
```
{% endcode-tabs-item %}
{% endcode-tabs %}

While unrealistic, this example demonstrates the various accepted [types][docs.config_value_types].




## How It Works

### Arrays

The `add_fields` transform will support [TOML arrays][url.toml_array]. Keep in mind that the values must be simple type (not tables), and each value must the same type. You cannot mix types:

```
[transforms.<transform-id>]
  # ...
  
  [transforms.<transform-id>.fields]
    my_array = ["first", "second", "third"]
```

### Complex Transforming

The `add_fields` transform is designed for simple key additions. If you need more complex transforming then we recommend using a more versatile transform like the [`lua` transform][docs.lua_transform].

### Environment Variables

As described in the [Configuration document][docs.configuration], Vector will interpolate environment variables in your configuration file. This can be helpful when adding fields, such as adding a `"host"` field as shown in the example.

### Key Conflicts

Keys specified in this transform will replace existing keys.

### Nested Fields

The `add_fields` transform will support dotted keys or [TOML tables][url.toml_table]. We recommend the dotted key syntax since it is less verbose for this usecase:

```
[transforms.<transform-id>]
  # ...
  
  [transforms.<transform-id>.fields]
    parent.child.grandchild = "<value>"
```

### Removing Fields

See the [`remove_fields` transform][docs.remove_fields_transform].

### Special Characters

Aside from the [special characters][docs.event_key_special_characters] listed in the [Data Model][docs.data_model] doc, Vector does not restrict the characters allowed in keys. You can wrap key names in `" "` quote to preserve spaces and use `\` to escape quotes.

### Value Types

All supported [configuration value types][docs.config_value_types] are accepted.

## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring_logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open transform issues](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+add_fields%22).
2. [Search the forum][url.search_forum] for any similar issues.
2. Reach out to the [community][url.community] for help.

### Alternatives

Finally, consider the following alternatives:

* [`remove_fields` transform][docs.remove_fields_transform]

## Resources

* [**Issues**](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+add_fields%22) - [enhancements](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+add_fields%22+label%3A%22Type%3A+Enhancement%22) - [bugs](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+add_fields%22+label%3A%22Type%3A+Bug%22)
* [**Source code**](https://github.com/timberio/vector/tree/master/src/transform/add_fields.rs)


[docs.config_composition]: ../../../usage/configuration/README.md#composition
[docs.config_value_types]: ../../../usage/configuration/README.md#value-types
[docs.configuration]: ../../../usage/configuration
[docs.data_model]: ../../../about/data-model.md
[docs.event_key_special_characters]: ../../../about/data-model.md#special-characters
[docs.log_event]: ../../../about/data-model.md#log
[docs.lua_transform]: ../../../usage/configuration/transforms/lua.md
[docs.monitoring_logs]: ../../../usage/administration/monitoring.md#logs
[docs.remove_fields_transform]: ../../../usage/configuration/transforms/remove_fields.md
[docs.sources]: ../../../usage/configuration/sources
[docs.transforms]: ../../../usage/configuration/transforms
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[url.community]: https://vector.dev/community
[url.search_forum]: https://forum.vector.dev/search?expanded=true
[url.toml_array]: https://github.com/toml-lang/toml#user-content-array
[url.toml_table]: https://github.com/toml-lang/toml#user-content-table
