---
description: parse a field value with Grok
---

<!---
!!!WARNING!!!!

This file is autogenerated! Please do not manually edit this file.
Instead, please modify the contents of `scripts/metadata.toml`.
-->


# grok_parser transform

![](../../../assets/grok_parser-transform.svg)


The `grok_parser` transforms accepts [`log`][docs.log_event] events and allows you to parse a field value with [Grok][url.grok].

## Config File

{% code-tabs %}
{% code-tabs-item title="example" %}
```coffeescript
[transforms.my_grok_parser_transform]
  # REQUIRED - General
  type = "grok_parser" # must be: grok_parser
  inputs = ["my-source-id"]
  pattern = "%{TIMESTAMP_ISO8601:timestamp} %{LOGLEVEL:level} %{GREEDYDATA:message}"

  # OPTIONAL - General
  drop_field = true # default
  field = "message" # default
```
{% endcode-tabs-item %}
{% code-tabs-item title="schema" %}
```coffeescript
[transforms.<transform-id>]
  # REQUIRED - General
  type = {"grok_parser"}
  inputs = "<string>"
  pattern = "<string>"

  # OPTIONAL - General
  drop_field = <bool>
  field = "<string>"
```
{% endcode-tabs-item %}
{% code-tabs-item title="specification" %}
```coffeescript
[transforms.grok_parser]
  # REQUIRED - General

  # The component type
  #
  # * must be: grok_parser
  type = "grok_parser"

  # A list of upstream source for more info.
  inputs = ["my-source-id"]

  # The Grok pattern
  pattern = "%{TIMESTAMP_ISO8601:timestamp} %{LOGLEVEL:level} %{GREEDYDATA:message}"

  # OPTIONAL - General

  # If `true` will drop the `field` after parsing.
  #
  # * default: true
  drop_field = true

  # The field to execute the `pattern` against. Must be a `string` value.
  #
  # * default: message
  field = "message"
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## Options

| Key  | Type  | Description |
| :--- | :---: | :---------- |
| **REQUIRED** | | |
| `type` | `string` | The component type<br />`required` `enum: "grok_parser"` |
| `inputs` | `string` | A list of upstream [source][docs.sources] or [transform][docs.transforms] IDs. See [Config Composition][docs.config_composition] for more info.<br />`required` `example: ["my-source-id"]` |
| `pattern` | `string` | The [Grok pattern][url.grok_patterns]<br />`required` `example: (see above)` |
| **OPTIONAL** | | |
| `drop_field` | `bool` | If `true` will drop the `field` after parsing.<br />`default: true` |
| `field` | `string` | The field to execute the `pattern` against. Must be a `string` value.<br />`default: "message"` |





## How It Works

### Debugging

We recommend the [Grok debugger][url.grok_debugger] for Grok testing.

### Patterns

Vector uses the Rust [`grok` library][url.rust_grok_library]. All patterns [listed here][url.grok_patterns] are supported. It is recommended to use any maintained patterns when possible.

### Performance

Grok is approximately 50% slower than it's Regex counterpart. We plan to add a [performance test][docs.performance] for this in the future. While this is still plenty fast for most use cases we recommend using the [`regex_parser` transform][docs.regex_parser_transform] if you are experiencing performance issues.

## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring_logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open transform issues](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+grok_parser%22).
2. [Search the forum][url.search_forum] for any similar issues.
2. Reach out to the [community][url.community] for help.

### Alternatives

Finally, consider the following alternatives:

* [`lua` transform][docs.lua_transform]
* [`regex_parser` transform][docs.regex_parser_transform]
* [`tokenizer` transform][docs.tokenizer_transform]

## Resources

* [**Issues**](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+grok_parser%22) - [enhancements](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+grok_parser%22+label%3A%22Type%3A+Enhancement%22) - [bugs](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+grok_parser%22+label%3A%22Type%3A+Bug%22)
* [**Source code**](https://github.com/timberio/vector/tree/master/src/transform/grok_parser.rs)
* [**Grok Debugger**][url.grok_debugger]
* [**Grok Patterns**][url.grok_patterns]


[docs.config_composition]: ../../../usage/configuration/README.md#composition
[docs.log_event]: ../../../about/data-model.md#log
[docs.lua_transform]: ../../../usage/configuration/transforms/lua.md
[docs.monitoring_logs]: ../../../usage/administration/monitoring.md#logs
[docs.performance]: ../../../performance.md
[docs.regex_parser_transform]: ../../../usage/configuration/transforms/regex_parser.md
[docs.sources]: ../../../usage/configuration/sources
[docs.tokenizer_transform]: ../../../usage/configuration/transforms/tokenizer.md
[docs.transforms]: ../../../usage/configuration/transforms
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[url.community]: https://vector.dev/community
[url.grok]: http://grokdebug.herokuapp.com/
[url.grok_debugger]: http://grokdebug.herokuapp.com/
[url.grok_patterns]: https://github.com/daschl/grok/tree/master/patterns
[url.rust_grok_library]: https://github.com/daschl/grok
[url.search_forum]: https://forum.vector.dev/search?expanded=true
