---
description: sample events with a configurable rate
---

<!---
!!!WARNING!!!!

This file is autogenerated! Please do not manually edit this file.
Instead, please modify the contents of `scripts/metadata.toml`.
-->


# sampler transform

![](../../../assets/sampler-transform.svg)

{% hint style="warning" %}
The `sampler` transform is in beta. Please see the current [enhancements](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+sampler%22+label%3A%22Type%3A+Enhancement%22) and [bugs](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+sampler%22+label%3A%22Type%3A+Bug%22) for known issues. We kindly ask that you [add any missing issues](https://github.com/timberio/vector/issues/new?labels=Transform%3A+sampler) as it will help shape the roadmap of this component.
{% endhint %}
The `sampler` transforms accepts [`log`][docs.log_event] events and allows you to sample events with a configurable rate.

## Config File

{% code-tabs %}
{% code-tabs-item title="example" %}
```coffeescript
[transforms.my_sampler_transform]
  # REQUIRED - General
  type = "sampler" # must be: sampler
  inputs = ["my-source-id"]

  # OPTIONAL - General
  pass_list = ["[error]", "field2"] # no default
  rate = ["field1", "field2"] # no default
```
{% endcode-tabs-item %}
{% code-tabs-item title="schema" %}
```coffeescript
[transforms.<transform-id>]
  # REQUIRED - General
  type = {"sampler"}
  inputs = "<string>"

  # OPTIONAL - General
  pass_list = ["<string>", ...
  rate = <int>
```
{% endcode-tabs-item %}
{% code-tabs-item title="specification" %}
```coffeescript
[transforms.sampler]
  # REQUIRED - General

  # The component type
  #
  # * must be: sampler
  type = "sampler"

  # A list of upstream source for more info.
  inputs = ["my-source-id"]

  # OPTIONAL - General

  # A list of regular expression patterns to exclude events from sampling. If an
  # event's `"message"` key matches _any_ of these patterns it will _not_ be
  # sampled.
  #
  # * no default
  pass_list = ["[error]", "field2"]

  # The maximum number of events allowed per second.
  #
  # * no default
  rate = ["field1", "field2"]
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## Options

| Key  | Type  | Description |
| :--- | :---: | :---------- |
| **REQUIRED** | | |
| `type` | `string` | The component type<br />`required` `enum: "sampler"` |
| `inputs` | `string` | A list of upstream [source][docs.sources] or [transform][docs.transforms] IDs. See [Config Composition][docs.config_composition] for more info.<br />`required` `example: ["my-source-id"]` |
| **OPTIONAL** | | |
| `pass_list` | `[string]` | A list of regular expression patterns to exclude events from sampling. If an event's `"message"` key matches _any_ of these patterns it will _not_ be sampled.<br />`no default` `example: ["[error]", "field2"]` |
| `rate` | `int` | The maximum number of events allowed per second.<br />`no default` `example: ["field1", "field2"]` |







## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring_logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open transform issues](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+sampler%22).
2. [Search the forum][url.search_forum] for any similar issues.
2. Reach out to the [community][url.community] for help.

## Resources

* [**Issues**](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+sampler%22) - [enhancements](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+sampler%22+label%3A%22Type%3A+Enhancement%22) - [bugs](https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22Transform%3A+sampler%22+label%3A%22Type%3A+Bug%22)
* [**Source code**](https://github.com/timberio/vector/tree/master/src/transform/sampler.rs)


[docs.config_composition]: ../../../usage/configuration/README.md#composition
[docs.log_event]: ../../../about/data-model.md#log
[docs.monitoring_logs]: ../../../usage/administration/monitoring.md#logs
[docs.sources]: ../../../usage/configuration/sources
[docs.transforms]: ../../../usage/configuration/transforms
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[url.community]: https://vector.dev/community
[url.search_forum]: https://forum.vector.dev/search?expanded=true
